Mousetail Documentation
=======================

Mousetail is a standalone MCP (Model Context Protocol) server that enables LLMs like Claude to interact with Anki flashcard collections using Anki's Python library.

Quick Start
-----------

For installation and usage instructions, see the `README <https://github.com/listfold/mousetail/blob/main/README.md>`_.

API Reference
-------------

The main value of this documentation is the comprehensive API reference:

.. toctree::
   :maxdepth: 2

   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
